@@ -27,7 +27,7 @@ phosh_calendar_class_init (PhoshCalendarClass *klass)
   g_type_ensure (GTK_TYPE_CALENDAR);
 
   gtk_widget_class_set_template_from_resource (widget_class,
-                                               "/sm/puri/phosh/plugins/calendar/calendar.ui");
+                                               "/mobi/phosh/plugins/calendar/calendar.ui");
 
   gtk_widget_class_set_css_name (widget_class, "phosh-calendar");
 }
@@ -41,7 +41,7 @@ phosh_calendar_init (PhoshCalendar *self)
 
   css_provider = gtk_css_provider_new ();
   gtk_css_provider_load_from_resource (css_provider,
-                                       "/sm/puri/phosh/plugins/calendar/stylesheet/common.css");
+                                       "/mobi/phosh/plugins/calendar/stylesheet/common.css");
   gtk_style_context_add_provider (gtk_widget_get_style_context (GTK_WIDGET (self)),
                                   GTK_STYLE_PROVIDER (css_provider),
                                   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
