@@ -71,14 +71,36 @@ ease_out_bounce (double t)
   return 7.5625 * p * p + 0.984375;
 }
 
+
+static double
+ease_in_quintic (double t)
+{
+  return t * t * t * t * t;
+} 
+
+
+static double
+ease_out_quintic (double t)
+{
+  double p = t - 1;
+
+  return p * p * p * p * p + 1;
+} 
+
+
 static inline double
-interpolate (PhoshAnimationType type,
-             double             t)
+interpolate (PhoshAnimationType type, double t)
 {
   switch (type) {
   case PHOSH_ANIMATION_TYPE_EASE_OUT_CUBIC:
     return hdy_ease_out_cubic (t);
 
+  case PHOSH_ANIMATION_TYPE_EASE_IN_QUINTIC:
+    return ease_in_quintic (t);
+    
+  case PHOSH_ANIMATION_TYPE_EASE_OUT_QUINTIC:
+    return ease_out_quintic (t);
+    
   case PHOSH_ANIMATION_TYPE_EASE_OUT_BOUNCE:
     return ease_out_bounce (t);
 
