@@ -22,12 +22,12 @@ typedef enum
 {
   /*< private >*/
   PHOSH_CALL_STATE_ACTIVE = 1,
-  PHOSH_CALL_STATE_HELD,
-  PHOSH_CALL_STATE_DIALING,
-  PHOSH_CALL_STATE_ALERTING,
-  PHOSH_CALL_STATE_INCOMING,
-  PHOSH_CALL_STATE_WAITING,
-  PHOSH_CALL_STATE_DISCONNECTED
+  PHOSH_CALL_STATE_HELD = 2,
+  PHOSH_CALL_STATE_DIALING = 3,
+  /* PHOSH_CALL_STATE_ALERTING (deprecated) */
+  PHOSH_CALL_STATE_INCOMING = 5,
+  /* PHOSH_CALL_STATE_WAITING (deprecated) */
+  PHOSH_CALL_STATE_DISCONNECTED = 7,
 } PhoshCallState;
 
 
