@@ -6,6 +6,7 @@
 #pragma once
 
 #include "drag-surface.h"
+#include "monitor/monitor.h"
 #include "overview.h"
 
 #include <gtk/gtk.h>
@@ -28,8 +29,9 @@ typedef enum {
 
 G_DECLARE_FINAL_TYPE (PhoshHome, phosh_home, PHOSH, HOME, PhoshDragSurface)
 
-GtkWidget * phosh_home_new (struct zwlr_layer_shell_v1 *layer_shell,
-                            struct zphoc_layer_shell_effects_v1 *layer_shell_effects,
-                            struct wl_output *wl_output);
-void phosh_home_set_state (PhoshHome *self, PhoshHomeState state);
+GtkWidget     *phosh_home_new (struct zwlr_layer_shell_v1          *layer_shell,
+                               struct zphoc_layer_shell_effects_v1 *layer_shell_effects,
+                               PhoshMonitor                        *monitor);
+PhoshHomeState phosh_home_get_state (PhoshHome *self);
+void           phosh_home_set_state (PhoshHome *self, PhoshHomeState state);
 PhoshOverview *phosh_home_get_overview (PhoshHome *self);
