@@ -94,7 +94,7 @@ typedef struct {
   GtkRevealer       *rev_call_notifications;
   GtkRevealer       *rev_media_player;
   GtkRevealer       *rev_notifications;
-  GSettings         *settings;
+  GSettings         *notification_settings;
   guint              reveals;
 
   /* unlock page */
@@ -109,7 +109,7 @@ typedef struct {
   guint              idle_timer;
   gint64             last_input;
   PhoshAuth         *auth;
-  GSettings         *keypad_settings;
+  GSettings         *lockscreen_settings;
 
   /* widget box */
   GtkWidget         *widget_box;
@@ -249,8 +249,11 @@ shake_label (GtkWidget     *widget,
   if (now > end_time) {
     /* Stop the animation only when we would step over the idle position (0.5) */
     if ((gtk_entry_get_alignment (GTK_ENTRY (priv->entry_pin)) > 0.5 && pos < 0.5) || pos > 0.5) {
+      guint id;
+
       gtk_entry_set_alignment (GTK_ENTRY (priv->entry_pin), 0.5);
-      g_timeout_add (400, (GSourceFunc) finish_shake_label, self);
+      id = g_timeout_add (400, (GSourceFunc) finish_shake_label, self);
+      g_source_set_name_by_id (id, "[PhoshLockscreen] shake label");
       return FALSE;
     }
   }
@@ -413,7 +416,7 @@ key_press_event_cb (PhoshLockscreen *self, GdkEventKey *event, gpointer data)
 {
   PhoshLockscreenPrivate *priv;
   gboolean handled = FALSE;
-  gboolean on_unlock_page;
+  gboolean on_unlock_page, with_control;
   double position;
 
   g_assert (PHOSH_IS_LOCKSCREEN (self));
@@ -422,6 +425,7 @@ key_press_event_cb (PhoshLockscreen *self, GdkEventKey *event, gpointer data)
   position = hdy_carousel_get_position (HDY_CAROUSEL (priv->carousel));
   /* Round to nearest page so we already accept keyboard input before animation ends */
   on_unlock_page = (int)round(position) == POS_UNLOCK;
+  with_control = event->state & GDK_CONTROL_MASK;
 
   if (gtk_entry_im_context_filter_keypress (GTK_ENTRY (priv->entry_pin), event)) {
     show_unlock_page (self);
@@ -453,6 +457,17 @@ key_press_event_cb (PhoshLockscreen *self, GdkEventKey *event, gpointer data)
         handled = TRUE;
       }
       break;
+    case GDK_KEY_Left:
+      if (!on_unlock_page && with_control && hdy_deck_get_can_swipe_back (priv->deck)) {
+        hdy_deck_navigate (priv->deck, HDY_NAVIGATION_DIRECTION_BACK);
+        handled = TRUE;
+      }
+      break;
+    case GDK_KEY_Right:
+      if (!on_unlock_page && with_control && hdy_deck_get_can_swipe_forward (priv->deck)) {
+        hdy_deck_navigate (priv->deck, HDY_NAVIGATION_DIRECTION_FORWARD);
+        handled = TRUE;
+      }
     default:
       /* nothing to do */
       break;
@@ -538,6 +553,7 @@ carousel_page_changed_cb (PhoshLockscreen *self,
       priv->idle_timer = g_timeout_add_seconds (LOCKSCREEN_IDLE_SECONDS,
                                                 (GSourceFunc) keypad_check_idle,
                                                 self);
+      g_source_set_name_by_id (priv->idle_timer, "[PhoshLockscreen] keypad check");
     }
   } else {
     g_assert_not_reached ();
@@ -748,7 +764,7 @@ on_notification_items_changed (PhoshLockscreen *self,
   g_return_if_fail (PHOSH_IS_LOCKSCREEN (self));
   priv = phosh_lockscreen_get_instance_private (self);
 
-  show_in_lockscreen = g_settings_get_boolean (priv->settings, "show-in-lock-screen");
+  show_in_lockscreen = g_settings_get_boolean (priv->notification_settings, "show-in-lock-screen");
   is_empty = !g_list_model_get_n_items (list);
 
   reveal = show_in_lockscreen && !is_empty;
@@ -817,7 +833,7 @@ phosh_lockscreen_constructed (GObject *object)
     update_active_call (self, active);
 
   manager = phosh_notify_manager_get_default ();
-  priv->settings = g_settings_new(NOTIFICATIONS_SCHEMA_ID);
+  priv->notification_settings = g_settings_new (NOTIFICATIONS_SCHEMA_ID);
   gtk_list_box_bind_model (GTK_LIST_BOX (priv->list_notifications),
                            G_LIST_MODEL (phosh_notify_manager_get_list (manager)),
                            create_notification_row,
@@ -843,8 +859,8 @@ phosh_lockscreen_constructed (GObject *object)
                           priv->btn_keyboard, "sensitive",
                           G_BINDING_SYNC_CREATE);
 
-  priv->keypad_settings = g_settings_new("sm.puri.phosh.lockscreen");
-  g_settings_bind (priv->keypad_settings, "shuffle-keypad",
+  priv->lockscreen_settings = g_settings_new ("sm.puri.phosh.lockscreen");
+  g_settings_bind (priv->lockscreen_settings, "shuffle-keypad",
                    priv->keypad, "shuffle",
                    G_SETTINGS_BIND_GET);
 
@@ -883,12 +899,12 @@ phosh_lockscreen_dispose (GObject *object)
   PhoshLockscreen *self = PHOSH_LOCKSCREEN (object);
   PhoshLockscreenPrivate *priv = phosh_lockscreen_get_instance_private (self);
 
-  g_clear_object (&priv->settings);
+  g_clear_object (&priv->notification_settings);
   g_clear_object (&priv->wall_clock);
   g_clear_handle_id (&priv->idle_timer, g_source_remove);
   g_clear_object (&priv->calls_manager);
   g_clear_pointer (&priv->active, g_free);
-  g_clear_object (&priv->keypad_settings);
+  g_clear_object (&priv->lockscreen_settings);
 
   G_OBJECT_CLASS (phosh_lockscreen_parent_class)->dispose (object);
 }
