@@ -199,12 +199,12 @@ network_prompt_setup_wifi_dialog (PhoshNetworkAuthPrompt *self)
     g_debug ("Network security method %d of %s not supported",
              self->security_type, ssid);
     str =  g_strdup_printf(_(
-      "Authentication type of wifi network “%s” not supported"), ssid);
+      "Authentication type of Wi-Fi network “%s” not supported"), ssid);
     gtk_label_set_label (GTK_LABEL (self->message_label), str);
     return;
   }
 
-  str = g_strdup_printf (_("Enter password for the wifi network “%s”"), ssid);
+  str = g_strdup_printf (_("Enter password for the Wi-Fi network “%s”"), ssid);
   gtk_label_set_label (GTK_LABEL (self->message_label), str);
 
   network_prompt_set_grid (self, self->wpa_grid);
