@@ -51,6 +51,8 @@ G_DEFINE_TYPE (PhoshNotifyFeedback, phosh_notify_feedback, G_TYPE_OBJECT)
 static void
 end_notify_feedback (PhoshNotifyFeedback *self)
 {
+  g_return_if_fail (lfb_is_initted ());
+
   if (self->event == NULL)
     return;
 
@@ -64,8 +66,6 @@ find_event (const char *category)
 {
   PhoshShell *shell = phosh_shell_get_default ();
   gboolean inactive = phosh_shell_get_blanked (shell) || phosh_shell_get_locked (shell);
-  /* If shell is unlocked and we don't have a specific category don't
-     trigger any event to not distract the user*/
   const char *ret = NULL;
 
   if (inactive) {
@@ -84,7 +84,7 @@ find_event (const char *category)
       ret = "message-new-instant";
     else if (g_strcmp0 (category, "x-gnome.call.unanswered") == 0)
       ret = "phone-missed-call";
-    /* no additional feedback when not locked */
+    /* no feedback when not locked as to not distract the user */
   }
 
   return ret;
@@ -122,11 +122,12 @@ maybe_trigger_feedback (PhoshNotifyFeedback *self, PhoshNotificationSource *sour
   for (int i = 0; i < num; i++) {
     g_autoptr (PhoshNotification) noti = g_list_model_get_item (G_LIST_MODEL (source), position + i);
     g_autoptr (LfbEvent) event = NULL;
-    const char *category, *event_name;
+    const char *category, *event_name, *profile;
     g_autofree char *app_id = NULL;
     GAppInfo *info = NULL;
 
     g_return_val_if_fail (PHOSH_IS_NOTIFICATION (noti), FALSE);
+    g_return_val_if_fail (lfb_is_initted (), FALSE);
 
     category = phosh_notification_get_category (noti);
     event_name = find_event (category);
@@ -137,8 +138,14 @@ maybe_trigger_feedback (PhoshNotifyFeedback *self, PhoshNotificationSource *sour
     if (info)
       app_id = phosh_strip_suffix_from_app_id (g_app_info_get_id (info));
 
-    g_debug ("Emitting event %s for %s", event_name, app_id ?: "unknown");
+    profile = phosh_notification_get_profile (noti);
+    if (g_strcmp0 (profile, "none") == 0)
+      continue;
+
+    g_debug ("Emitting event %s for %s, profile: %s",
+             event_name, app_id ?: "unknown", profile);
     event = lfb_event_new (event_name);
+    lfb_event_set_feedback_profile (event, profile);
     g_set_object (&self->event, event);
 
     if (app_id)
