@@ -19,11 +19,22 @@
  *
  * A quick setting for the notification drawer
  *
- * The #PhoshQuickSetting is a widget which is meant to be placed inside the top drawer.
- * It contains a #GtkLabel and accepts one #PhoshStatusIcon as a child. The info property
- * of the #PhoshStatusIcon is bind to the #GtkLabel.
- * A #PhoshQuickSetting has two signals long_press and clicked, where the first is emitted
- * when the user performs a long press, the second signal is a normal single click.
+ * The `PhoshQuickSetting` is a widget which is meant to be placed inside the top drawer.
+ * It contains a [type@Gtk.Label] and accepts one [type@StatusIcon] as a child. The
+ * [type@StatusIcon]'s [property@StatusIcon:info] property is automatically bound to the
+ * `PhoshQuickSetting`'s [type@Gtk.Label].
+ *
+ * If the [type@StatusIcon] has an `enabled` property it will be automatically bound to
+ * to the `PhoshQuickSetting`'s [property@QuickSetting:active] property to make the quick setting appear
+ * enabled/disabled whenever the status icon changes state.
+ *
+ * A `PhoshQuickSetting` has a [signal@QuickSetting::long-pressed] signal that is emitted when
+ * the user performs a long press. In order to react on single press connect to the [type@Gtk.Button]'s
+ * [signal@Gtk.Button::clicked] signal.
+ *
+ * `PhoshQuickSetting` has a [property@Phosh.QuickSetting:present] property which can be used to set
+ * if the quick setting is available. For example, a Wi-Fi quick setting is available only when the
+ * appropriate hardware is present.
  */
 
 enum {
@@ -37,18 +48,21 @@ enum {
   PROP_0,
   PROP_STATUS_ICON,
   PROP_ACTIVE,
+  PROP_PRESENT,
+  PROP_HAS_STATUS,
   PROP_LAST_PROP
 };
 static GParamSpec *props[PROP_LAST_PROP];
 
-typedef struct
-{
-  GtkWidget *box;
+typedef struct {
+  GtkWidget       *box;
   PhoshStatusIcon *status_icon;
-  GtkWidget *label;
-  GBinding *label_binding;
-  GtkGesture *long_press;
-  gboolean    active;
+  GtkWidget       *label;
+  GtkWidget       *has_status_image;
+  GBinding        *label_binding;
+  GtkGesture      *long_press;
+  gboolean         active;
+  gboolean         present;
 } PhoshQuickSettingPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (PhoshQuickSetting, phosh_quick_setting, GTK_TYPE_BUTTON);
@@ -63,20 +77,26 @@ phosh_quick_setting_set_property (GObject      *object,
   PhoshQuickSetting *self = PHOSH_QUICK_SETTING (object);
 
   switch (property_id) {
-    case PROP_ACTIVE:
-      phosh_quick_setting_set_active (self, g_value_get_boolean (value));
-      break;
-    default:
-      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
-      break;
+  case PROP_ACTIVE:
+    phosh_quick_setting_set_active (self, g_value_get_boolean (value));
+    break;
+  case PROP_PRESENT:
+    phosh_quick_setting_set_present (self, g_value_get_boolean (value));
+    break;
+  case PROP_HAS_STATUS:
+    phosh_quick_setting_set_has_status (self, g_value_get_boolean (value));
+    break;
+  default:
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+    break;
   }
 }
 
 
 static void
-phosh_quick_setting_get_property (GObject *object,
-                                  guint property_id,
-                                  GValue *value,
+phosh_quick_setting_get_property (GObject    *object,
+                                  guint       property_id,
+                                  GValue     *value,
                                   GParamSpec *pspec)
 {
   PhoshQuickSetting *self = PHOSH_QUICK_SETTING (object);
@@ -88,6 +108,12 @@ phosh_quick_setting_get_property (GObject *object,
   case PROP_ACTIVE:
     g_value_set_boolean (value, phosh_quick_setting_get_active (self));
     break;
+  case PROP_PRESENT:
+    g_value_set_boolean (value, phosh_quick_setting_get_present (self));
+    break;
+  case PROP_HAS_STATUS:
+    g_value_set_boolean (value, phosh_quick_setting_get_has_status (self));
+    break;
   default:
     G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
   }
@@ -132,7 +158,7 @@ phosh_quick_setting_add (GtkContainer *container, GtkWidget *child)
                                                 "label",
                                                 G_BINDING_SYNC_CREATE);
 
-  /* child's aren't required to have an `enabled` property */
+  /* The child isn't required to have an `enabled` property */
   if (g_object_class_find_property (G_OBJECT_GET_CLASS (child), "enabled")) {
       priv->label_binding = g_object_bind_property (child,
                                                     "enabled",
@@ -186,7 +212,6 @@ button_pressed_cb (PhoshQuickSetting *self, GdkEventButton *event, GtkButton *bu
 }
 
 
-
 static void
 phosh_quick_setting_class_init (PhoshQuickSettingClass *klass)
 {
@@ -222,6 +247,26 @@ phosh_quick_setting_class_init (PhoshQuickSettingClass *klass)
                           FALSE,
                           G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
+  /**
+   * PhoshQuickSetting:present:
+   *
+   * Whether the quick setting is available.
+   */
+  props[PROP_PRESENT] =
+    g_param_spec_boolean ("present", "", "",
+                          TRUE,
+                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+
+  /**
+   * PhoshQuickSetting:has-status:
+   *
+   * Whether the quick setting has a status page
+   */
+  props[PROP_HAS_STATUS] =
+    g_param_spec_boolean ("has-status", "", "",
+                          FALSE,
+                          G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+
   g_object_class_install_properties (object_class, PROP_LAST_PROP, props);
 
   signals[LONG_PRESSED] = g_signal_new ("long-pressed",
@@ -237,6 +282,7 @@ phosh_quick_setting_class_init (PhoshQuickSettingClass *klass)
                                                "/sm/puri/phosh/ui/quick-setting.ui");
 
   gtk_widget_class_bind_template_child_private (widget_class, PhoshQuickSetting, box);
+  gtk_widget_class_bind_template_child_private (widget_class, PhoshQuickSetting, has_status_image);
   gtk_widget_class_bind_template_child_private (widget_class, PhoshQuickSetting, label);
   gtk_widget_class_bind_template_child_private (widget_class, PhoshQuickSetting, long_press);
   gtk_widget_class_bind_template_callback (widget_class, long_pressed_cb);
@@ -314,13 +360,13 @@ create_dbus_proxy_cb (GObject *source_object, GAsyncResult *res, char *panel)
   params[2] = g_variant_new_array (G_VARIANT_TYPE ("{sv}"), NULL, 0);
 
   g_dbus_proxy_call (proxy,
-		     "Activate",
-		     g_variant_new_tuple (params, 3),
-		     G_DBUS_CALL_FLAGS_NONE,
-		     -1,
-		     NULL,
-		     (GAsyncReadyCallback) call_dbus_cb,
-		     g_steal_pointer (&panel));
+                     "Activate",
+                     g_variant_new_tuple (params, 3),
+                     G_DBUS_CALL_FLAGS_NONE,
+                     -1,
+                     NULL,
+                     (GAsyncReadyCallback) call_dbus_cb,
+                     g_steal_pointer (&panel));
 }
 
 
@@ -328,14 +374,14 @@ void
 phosh_quick_setting_open_settings_panel (const char *panel)
 {
   g_dbus_proxy_new_for_bus (G_BUS_TYPE_SESSION,
-			    G_DBUS_PROXY_FLAGS_NONE,
-			    NULL,
-			    "org.gnome.Settings",
-			    "/org/gnome/Settings",
-			    "org.gtk.Actions",
-			    NULL,
-			    (GAsyncReadyCallback) create_dbus_proxy_cb,
-			    g_strdup (panel));
+                            G_DBUS_PROXY_FLAGS_NONE,
+                            NULL,
+                            "org.gnome.Settings",
+                            "/org/gnome/Settings",
+                            "org.gtk.Actions",
+                            NULL,
+                            (GAsyncReadyCallback) create_dbus_proxy_cb,
+                            g_strdup (panel));
 
 }
 
@@ -369,3 +415,61 @@ phosh_quick_setting_get_active (PhoshQuickSetting *self)
 
   return priv->active;
 }
+
+
+void
+phosh_quick_setting_set_present (PhoshQuickSetting *self, gboolean present)
+{
+  PhoshQuickSettingPrivate *priv;
+
+  g_return_if_fail (PHOSH_IS_QUICK_SETTING (self));
+  priv = phosh_quick_setting_get_instance_private (self);
+
+  if (priv->present == present)
+    return;
+
+  priv->present = present;
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_PRESENT]);
+}
+
+
+gboolean
+phosh_quick_setting_get_present (PhoshQuickSetting *self)
+{
+  PhoshQuickSettingPrivate *priv;
+
+  g_return_val_if_fail (PHOSH_IS_QUICK_SETTING (self), FALSE);
+  priv = phosh_quick_setting_get_instance_private (self);
+
+  return priv->present;
+}
+
+
+void
+phosh_quick_setting_set_has_status (PhoshQuickSetting *self, gboolean has_status)
+{
+  PhoshQuickSettingPrivate *priv;
+
+  g_return_if_fail (PHOSH_IS_QUICK_SETTING (self));
+  priv = phosh_quick_setting_get_instance_private (self);
+
+  if (gtk_widget_get_visible (priv->has_status_image) == has_status)
+    return;
+
+  gtk_widget_set_visible (priv->has_status_image, has_status);
+
+  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_HAS_STATUS]);
+}
+
+
+gboolean
+phosh_quick_setting_get_has_status (PhoshQuickSetting *self)
+{
+  PhoshQuickSettingPrivate *priv;
+
+  g_return_val_if_fail (PHOSH_IS_QUICK_SETTING (self), FALSE);
+  priv = phosh_quick_setting_get_instance_private (self);
+
+  return gtk_widget_get_visible (priv->has_status_image);
+}
