@@ -51,6 +51,7 @@ typedef struct _PhoshRotationManager {
   PhoshMonitor            *monitor;
   PhoshMonitorTransform    transform;
   PhoshMonitorTransform    prelock_transform;
+  gboolean                 blanked;
 
   GSettings               *settings;
   gboolean                 orientation_locked;
@@ -72,12 +73,11 @@ apply_transform (PhoshRotationManager *self, PhoshMonitorTransform transform)
   if (!self->monitor)
     return;
 
-  g_debug ("Rotating %s: %d", self->monitor->name, transform);
-
   current = phosh_monitor_get_transform (self->monitor);
   if (current == transform)
     return;
 
+  g_debug ("Rotating %s to %d", self->monitor->name, transform);
   phosh_monitor_manager_set_monitor_transform (monitor_manager,
                                                self->monitor,
                                                transform);
@@ -91,22 +91,24 @@ apply_transform (PhoshRotationManager *self, PhoshMonitorTransform transform)
  * Match the screen orientation to the sensor output.
  * Do nothing if orientation lock is on or there's no
  * sensor claimed.
+ *
+ * Returns: %TRUE if the orientation was matched, otherwise %FALSE.
  */
-static void
+static gboolean
 match_orientation (PhoshRotationManager *self)
 {
   const gchar *orient;
   PhoshMonitorTransform transform;
 
   if (self->orientation_locked || !self->claimed ||
+      phosh_lockscreen_manager_get_locked (self->lockscreen_manager) ||
       self->mode == PHOSH_ROTATION_MANAGER_MODE_OFF)
-    return;
+    return FALSE;
 
   orient = phosh_dbus_sensor_proxy_get_accelerometer_orientation (
     PHOSH_DBUS_SENSOR_PROXY (self->sensor_proxy_manager));
 
-  g_debug ("Orientation changed: %s, locked: %d, claimed: %d",
-           orient, self->orientation_locked, self->claimed);
+  g_debug ("Orientation changed: %s", orient);
 
   if (!g_strcmp0 ("normal", orient)) {
     transform = PHOSH_MONITOR_TRANSFORM_NORMAL;
@@ -117,13 +119,14 @@ match_orientation (PhoshRotationManager *self)
   } else if (!g_strcmp0 ("left-up", orient)) {
     transform = PHOSH_MONITOR_TRANSFORM_90;
   } else if (!g_strcmp0 ("undefined", orient)) {
-    return; /* just leave as is */
+    return FALSE; /* just leave as is */
   } else {
     g_warning ("Unknown orientation '%s'", orient);
-    return;
+    return FALSE;
   }
 
   apply_transform (self, transform);
+  return TRUE;
 }
 
 static void
@@ -172,7 +175,7 @@ on_accelerometer_released (PhoshSensorProxyManager *sensor_proxy_manager,
     return;
   }
 
-  g_debug ("Released rotation sensor");
+  g_debug ("Released accelerometer");
   self->claimed = FALSE;
 }
 
@@ -185,6 +188,7 @@ phosh_rotation_manager_claim_accelerometer (PhoshRotationManager *self, gboolean
   if (!self->sensor_proxy_manager)
     return;
 
+  g_debug ("Claiming accelerometer: %d", claim);
   if (claim) {
     phosh_dbus_sensor_proxy_call_claim_accelerometer (
       PHOSH_DBUS_SENSOR_PROXY (self->sensor_proxy_manager),
@@ -220,17 +224,22 @@ on_has_accelerometer_changed (PhoshRotationManager    *self,
 /**
  * fixup_lockscreen_orientation:
  * @self: The PhoshRotationManager
- * @force: Whether to force the monitor to portait orientation
+ * @lock: %True if the screen is being locked, %FALSE for unlock
  *
  * On phones the lock screen doesn't work in landscape so fix that up
- * until https://source.puri.sm/Librem5/phosh/-/issues/388
- * is fixed. Keep all of this local to this function.
+ * by rotating to portrait on lock and back to the old orientation on
+ * unlock.
+ *
+ * See https://source.puri.sm/Librem5/phosh/-/issues/388
+ *
+ * Keep all of this local to this function.
  */
 static void
-fixup_lockscreen_orientation (PhoshRotationManager *self, gboolean force)
+fixup_lockscreen_orientation (PhoshRotationManager *self, gboolean lock)
 {
   PhoshShell *shell = phosh_shell_get_default ();
   PhoshModeManager *mode_manager = phosh_shell_get_mode_manager(shell);
+  PhoshMonitorTransform transform;
 
   g_return_if_fail (PHOSH_IS_MODE_MANAGER (mode_manager));
 
@@ -246,22 +255,27 @@ fixup_lockscreen_orientation (PhoshRotationManager *self, gboolean force)
   if (!phosh_monitor_is_builtin (self->monitor))
     return;
 
-  if (phosh_lockscreen_manager_get_locked (self->lockscreen_manager)) {
-    if (force) {
-      PhoshMonitorTransform transform;
-      /* Use prelock transform if portrait, else use normal */
-      transform = (self->prelock_transform % 2) == 0 ? self->prelock_transform :
-        PHOSH_MONITOR_TRANSFORM_NORMAL;
-      g_debug ("Forcing portrait transform: %d", transform);
-      apply_transform (self, transform);
-    } else {
+  if (lock) {
+    if (self->prelock_transform == -1) {
       self->prelock_transform = phosh_monitor_get_transform (self->monitor);
-      g_debug ("Saving transform %d", self->prelock_transform);
+      g_debug ("Saving prelock transform %d", self->prelock_transform);
     }
+
+    /* Use prelock transform if portrait, else use normal */
+    transform = (self->prelock_transform % 2) == 0 ? self->prelock_transform :
+      PHOSH_MONITOR_TRANSFORM_NORMAL;
+    g_debug ("Forcing portrait transform: %d", transform);
   } else {
+    if (self->prelock_transform == -1) {
+      g_warning ("Prelock transform invalid");
+      self->prelock_transform = PHOSH_MONITOR_TRANSFORM_NORMAL;
+    }
     g_debug ("Restoring transform %d", self->prelock_transform);
-    apply_transform (self, self->prelock_transform);
+    transform = self->prelock_transform;
+    self->prelock_transform = -1;
   }
+
+  apply_transform (self, transform);
 }
 
 
@@ -270,8 +284,8 @@ claim_or_release_accelerometer (PhoshRotationManager *self)
 {
   gboolean claim = TRUE;
 
-  /* No need for accel on screen lock, saves power */
-  if (phosh_lockscreen_manager_get_locked (self->lockscreen_manager))
+  /* No need for accel on screen blank, saves power */
+  if (phosh_shell_get_state (phosh_shell_get_default ()) & PHOSH_STATE_BLANKED)
     claim = FALSE;
 
   /* No need for accel on orientation lock, saves power */
@@ -289,6 +303,40 @@ claim_or_release_accelerometer (PhoshRotationManager *self)
 }
 
 
+static void
+on_shell_state_changed (PhoshRotationManager  *self,
+                        GParamSpec            *pspec,
+                        PhoshShell            *shell)
+{
+  PhoshShellStateFlags state;
+  gboolean blanked;
+
+  g_return_if_fail (PHOSH_IS_ROTATION_MANAGER (self));
+  g_return_if_fail (PHOSH_IS_SHELL (shell));
+
+  state = phosh_shell_get_state (shell);
+  g_debug ("Shell state changed: %d", state);
+
+  blanked = !!(phosh_shell_get_state (phosh_shell_get_default ()) & PHOSH_STATE_BLANKED);
+
+  /* We're only interested in blank state changed */
+  if (blanked == self->blanked)
+    return;
+  self->blanked = blanked;
+
+  /* Claim/unclaim sensor if blank state changed */
+  claim_or_release_accelerometer (self);
+
+  if (blanked)
+    return;
+
+  /* Fixup lockscreen orientation on unblank */
+  if (!blanked && phosh_lockscreen_manager_get_locked (self->lockscreen_manager)) {
+      fixup_lockscreen_orientation (self, TRUE);
+  }
+}
+
+
 static void
 on_lockscreen_manager_locked (PhoshRotationManager *self, GParamSpec *pspec,
                               PhoshLockscreenManager *lockscreen_manager)
@@ -298,10 +346,18 @@ on_lockscreen_manager_locked (PhoshRotationManager *self, GParamSpec *pspec,
   g_return_if_fail (PHOSH_IS_ROTATION_MANAGER (self));
   g_return_if_fail (PHOSH_IS_LOCKSCREEN_MANAGER (lockscreen_manager));
 
-  claim_or_release_accelerometer (self);
-
   locked = phosh_lockscreen_manager_get_locked (self->lockscreen_manager);
-  fixup_lockscreen_orientation (self, locked);
+
+  if (locked) {
+    fixup_lockscreen_orientation (self, TRUE);
+  } else {
+    gboolean matched = match_orientation (self);
+
+    /* If we couldn't match the orientation (either because it was inhibited or it failed)
+       use the last known transform */
+    if (!matched)
+      fixup_lockscreen_orientation (self, FALSE);
+  }
 }
 
 
@@ -421,6 +477,13 @@ phosh_rotation_manager_constructed (GObject *object)
                             self);
   on_lockscreen_manager_locked (self, NULL, self->lockscreen_manager);
 
+  self->blanked = !!(phosh_shell_get_state (phosh_shell_get_default ()) & PHOSH_STATE_BLANKED);
+  g_signal_connect_object (phosh_shell_get_default (),
+                           "notify::shell-state",
+                           G_CALLBACK (on_shell_state_changed),
+                           self,
+                           G_CONNECT_SWAPPED);
+
   if (!self->sensor_proxy_manager) {
     g_message ("Got no sensor-proxy, no automatic rotation");
     return;
