@@ -15,7 +15,13 @@
 /**
  * PhoshStatusIcon:
  *
- * Base clase for different status icons e.g in the top bar
+ * Base class for status icons used in the Phosh's top-bar or in
+ * [type@QuickSetting]s. It's very common to have the same status icon
+ * class used for both places.
+ *
+ * If the widget will be used in a [type@QuickSetting] it is
+ * recommended (but not required) that derived classes implement a
+ * `enabled` property.
  */
 
 enum {
@@ -42,10 +48,10 @@ G_DEFINE_TYPE_WITH_PRIVATE (PhoshStatusIcon, phosh_status_icon, GTK_TYPE_BIN);
 
 
 static void
-phosh_status_icon_set_property (GObject *object,
-                                  guint property_id,
-                                  const GValue *value,
-                                  GParamSpec *pspec)
+phosh_status_icon_set_property (GObject      *object,
+                                guint         property_id,
+                                const GValue *value,
+                                GParamSpec   *pspec)
 {
   PhoshStatusIcon *self = PHOSH_STATUS_ICON (object);
 
@@ -69,10 +75,10 @@ phosh_status_icon_set_property (GObject *object,
 
 
 static void
-phosh_status_icon_get_property (GObject *object,
-                                  guint property_id,
-                                  GValue *value,
-                                  GParamSpec *pspec)
+phosh_status_icon_get_property (GObject    *object,
+                                guint       property_id,
+                                GValue     *value,
+                                GParamSpec *pspec)
 {
   PhoshStatusIcon *self = PHOSH_STATUS_ICON (object);
 
@@ -118,8 +124,10 @@ phosh_status_icon_constructed (GObject *object)
 
   G_OBJECT_CLASS (phosh_status_icon_parent_class)->constructed (object);
 
-  if (klass->idle_init)
+  if (klass->idle_init) {
     priv->idle_id = g_idle_add ((GSourceFunc) on_idle, self);
+    g_source_set_name_by_id (priv->idle_id, "[PhoshStatusIcon] idle");
+  }
 }
 
 
@@ -160,34 +168,46 @@ phosh_status_icon_class_init (PhoshStatusIconClass *klass)
 
   gtk_widget_class_set_css_name (widget_class, "phosh-status-icon");
 
+  /**
+   * PhoshStatusIcon:icon-name:
+   *
+   * The name of the icon to display in the widget
+   */
   props[PHOSH_STATUS_ICON_PROP_ICON_NAME] =
-   g_param_spec_string ("icon-name",
-                        "icon name",
-                        "The icon name",
-                        NULL,
-                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
-
+    g_param_spec_string ("icon-name", "", "",
+                         NULL,
+                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+  /**
+   * PhoshStatusIcon:icon-size:
+   *
+   * The size of the icon to display in the widget
+   */
   props[PHOSH_STATUS_ICON_PROP_ICON_SIZE] =
-   g_param_spec_enum ("icon-size",
-		      "icon size",
-		      "The icon size",
-		      GTK_TYPE_ICON_SIZE,
-		      GTK_ICON_SIZE_LARGE_TOOLBAR,
-		      G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
-
+    g_param_spec_enum ("icon-size", "", "",
+                       GTK_TYPE_ICON_SIZE,
+                       GTK_ICON_SIZE_LARGE_TOOLBAR,
+                       G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+  /**
+   * PhoshStatusIcon:extra-widget:
+   *
+   * An extra widget to display. This is used for extra information when
+   * used in [type@TopPanel]. When used in [type@QuickSetting] this
+   * is not needed.
+   */
   props[PHOSH_STATUS_ICON_PROP_EXTRA_WIDGET] =
-   g_param_spec_object ("extra_widget",
-			"extra widget",
-			"An additional widget",
-			GTK_TYPE_WIDGET,
-			G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
-
+    g_param_spec_object ("extra_widget", "", "",
+                         GTK_TYPE_WIDGET,
+                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+  /**
+   * PhoshStatusIcon:info:
+   *
+   * Textual information to display. Think of it as the [type@StatusIcon]'s
+   * label.
+   */
   props[PHOSH_STATUS_ICON_PROP_INFO] =
-   g_param_spec_string ("info",
-                        "info",
-                        "Additional state information",
-                        NULL,
-                        G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+    g_param_spec_string ("info", "", "",
+                         NULL,
+                         G_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, PHOSH_STATUS_ICON_PROP_LAST_PROP, props);
 }
@@ -238,8 +258,8 @@ phosh_status_icon_set_icon_name (PhoshStatusIcon *self, const char *icon_name)
     return;
 
   gtk_image_set_from_icon_name (GTK_IMAGE (priv->image),
-				icon_name,
-				phosh_status_icon_get_icon_size (self));
+                                icon_name,
+                                phosh_status_icon_get_icon_size (self));
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PHOSH_STATUS_ICON_PROP_ICON_NAME]);
 }
