@@ -143,7 +143,7 @@ update_drag_handle (PhoshTopPanel *self, gboolean commit)
 
   /* By default only the bottom bar handle is draggable */
   handle = phosh_layer_surface_get_configured_height (PHOSH_LAYER_SURFACE (self));
-  handle -= PHOSH_TOP_PANEL_HEIGHT;
+  handle -= PHOSH_TOP_BAR_HEIGHT;
 
   /* Settings might enlarge the draggable area */
   offset = phosh_settings_get_drag_handle_offset (PHOSH_SETTINGS (self->settings));
@@ -441,7 +441,7 @@ phosh_top_panel_dragged (PhoshDragSurface *drag_surface, int margin)
   PhoshTopPanel *self = PHOSH_TOP_PANEL (drag_surface);
   int width, height;
   gtk_window_get_size (GTK_WINDOW (self), &width, &height);
-  phosh_arrow_set_progress (PHOSH_ARROW (self->arrow), -margin / (double)(height - PHOSH_TOP_PANEL_HEIGHT));
+  phosh_arrow_set_progress (PHOSH_ARROW (self->arrow), -margin / (double)(height - PHOSH_TOP_BAR_HEIGHT));
   g_debug ("Margin: %d", margin);
 }
 
@@ -624,7 +624,7 @@ phosh_top_panel_dispose (GObject *object)
 static int
 get_margin (gint height)
 {
-  return (-1 * height) + PHOSH_TOP_PANEL_HEIGHT;
+  return (-1 * height) + PHOSH_TOP_BAR_HEIGHT;
 }
 
 
@@ -766,12 +766,27 @@ set_clock_position (PhoshTopPanel *self, PhoshLayoutManager *layout_manager)
   gtk_widget_set_margin_top (self->box_clock, top_margin);
 }
 
+
+static void
+set_margin (PhoshTopPanel *self, PhoshLayoutManager *layout_manager)
+{
+  guint shift;
+
+  shift = phosh_layout_manager_get_corner_shift (layout_manager);
+  g_debug ("Shifting UI elements %d pixels to center ", shift);
+
+  gtk_widget_set_margin_start (GTK_WIDGET (self->box_top_bar), shift);
+  gtk_widget_set_margin_end (GTK_WIDGET (self->box_top_bar), shift);
+}
+
+
 static void
 on_layout_changed (PhoshTopPanel *self, PhoshLayoutManager *layout_manager)
 {
   g_return_if_fail (PHOSH_IS_TOP_PANEL (self));
   g_return_if_fail (PHOSH_IS_LAYOUT_MANAGER (layout_manager));
 
+  set_margin (self, layout_manager);
   set_clock_position (self, layout_manager);
 }
 
@@ -807,7 +822,7 @@ phosh_top_panel_new (struct zwlr_layer_shell_v1          *layer_shell,
                        /* layer-surface */
                        "layer-shell", layer_shell,
                        "wl-output", monitor->wl_output,
-                       "height", PHOSH_TOP_PANEL_HEIGHT,
+                       "height", PHOSH_TOP_BAR_HEIGHT,
                        "anchor", ZWLR_LAYER_SURFACE_V1_ANCHOR_TOP |
                                  ZWLR_LAYER_SURFACE_V1_ANCHOR_LEFT |
                                  ZWLR_LAYER_SURFACE_V1_ANCHOR_RIGHT,
@@ -816,7 +831,7 @@ phosh_top_panel_new (struct zwlr_layer_shell_v1          *layer_shell,
                        "namespace", "phosh top-panel",
                        /* drag-surface */
                        "layer-shell-effects", layer_shell_effects,
-                       "exclusive", PHOSH_TOP_PANEL_HEIGHT,
+                       "exclusive", PHOSH_TOP_BAR_HEIGHT,
                        "threshold", PHOSH_TOP_PANEL_DRAG_THRESHOLD,
                        NULL);
 }
