@@ -19,7 +19,7 @@ test_end_session_dialog_new (PhoshTestCompositorFixture *fixture, gconstpointer
   GtkWidget *dialog;
 
   dialog = g_object_new (PHOSH_TYPE_END_SESSION_DIALOG,
-                         "monitor", phosh_test_get_monitor (),
+                         "monitor", phosh_test_get_monitor (fixture->state),
                          "action", PHOSH_END_SESSION_ACTION_LOGOUT,
                          "timeout", 0,
                          "inhibitor-paths", NULL,
@@ -56,15 +56,15 @@ on_closed (GMainLoop *mainloop)
 static void
 test_end_session_dialog_timeout (PhoshTestCompositorFixture *fixture, gconstpointer unused)
 {
-  g_autoptr (PhoshEndSessionDialog) dialog = NULL;
+  PhoshEndSessionDialog *dialog = NULL;
   g_autoptr (GMainLoop) mainloop = NULL;
 
-  dialog = g_object_ref_sink (g_object_new (PHOSH_TYPE_END_SESSION_DIALOG,
-                                            "monitor", phosh_test_get_monitor (),
-                                            "action", PHOSH_END_SESSION_ACTION_LOGOUT,
-                                            "timeout", 1,
-                                            "inhibitor-paths", NULL,
-                                            NULL));
+  dialog = g_object_new (PHOSH_TYPE_END_SESSION_DIALOG,
+                         "monitor", phosh_test_get_monitor (fixture->state),
+                         "action", PHOSH_END_SESSION_ACTION_LOGOUT,
+                         "timeout", 1,
+                         "inhibitor-paths", NULL,
+                         NULL);
   g_assert_true (PHOSH_IS_END_SESSION_DIALOG (dialog));
 
   mainloop = g_main_loop_new (NULL, FALSE);
@@ -76,6 +76,8 @@ test_end_session_dialog_timeout (PhoshTestCompositorFixture *fixture, gconstpoin
   g_main_loop_run (mainloop);
   /* Letting the dialog timeout means confirmation */
   g_assert_true (phosh_end_session_dialog_get_action_confirmed (dialog));
+
+  gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
 
