@@ -334,7 +334,7 @@ main (int argc, char *argv[])
 
   g_test_init (&argc, &argv, NULL);
 
-  cfg = phosh_test_full_shell_fixture_cfg_new (NULL, "all");
+  cfg = phosh_test_full_shell_fixture_cfg_new ("all");
 
   g_test_add ("/phosh/dbus/gtk-mount-manager/ask-password",
               Fixture,
