@@ -47,7 +47,7 @@ main (int argc, char *argv[])
                 NULL);
 
   win = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  g_signal_connect (win, "delete_event", G_CALLBACK (gtk_main_quit), NULL);
+  g_signal_connect (win, "delete-event", G_CALLBACK (gtk_main_quit), NULL);
 
   gtk_widget_show (win);
 
